Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/blenfont/intern/blf_internal_types.h')
-rw-r--r--source/blender/blenfont/intern/blf_internal_types.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/blender/blenfont/intern/blf_internal_types.h b/source/blender/blenfont/intern/blf_internal_types.h
index 362cbf6730f..34b674670fd 100644
--- a/source/blender/blenfont/intern/blf_internal_types.h
+++ b/source/blender/blenfont/intern/blf_internal_types.h
@@ -65,6 +65,9 @@ typedef struct GlyphCacheBLF {
/* and dpi. */
unsigned int dpi;
+ bool bold;
+ bool italic;
+
/* and the glyphs. */
ListBase bucket[257];
@@ -218,13 +221,10 @@ typedef struct FontBLF {
/* font options. */
int flags;
- /* list of glyph cache for this font. */
- ListBase cache;
-
- /* current glyph cache, size and dpi.
+ /* List of glyph caches (GlyphCacheBLF) for this font for size, dpi, bold, italic.
* Use blf_glyph_cache_acquire(font) and blf_glyph_cache_release(font) to access cache!
*/
- GlyphCacheBLF *glyph_cache;
+ ListBase cache;
/* list of kerning cache for this font. */
ListBase kerning_caches;